<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.qiibee.com
 * @since      1.0.0
 *
 * @package    Qiibee_Connect
 * @subpackage Qiibee_Connect/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Qiibee_Connect
 * @subpackage Qiibee_Connect/admin
 * @author     qiibee <admin@qiibee.com>
 */
class Qiibee_Connect_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
  	$this->load_dependencies();

	}

  /**
	 * Load the required dependencies for the Admin facing functionality.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Wppb_Demo_Plugin_Admin_Settings. Registers the admin settings and page.
	 *
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
    add_action( 'woocommerce_order_status_completed', $this->wdm_send_order_to_ext);
    add_action( 'woocommerce_order_status_processing', $this->wdm_send_order_to_ext);

		require_once plugin_dir_path( dirname( __FILE__ ) ) .  'admin/class-qiibee-connect-settings.php';

	}
  
  
    
   public function wdm_send_order_to_ext( $order_id ){
    $order = new WC_Order( $order_id ); 
    $jsonData =json_encode($order->get_data());

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, 'https://whapi.qiibee.com/woocommerce');
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt( $ch, CURLOPT_POSTFIELDS, $jsonData );
    curl_setopt( $ch, CURLOPT_HTTPHEADER, [ 
      "X-API-Key: ".$apikey,
      'Content-Type:application/json']);
    curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
    $result = curl_exec($ch);
    curl_close($ch);

    echo $result;
    exit;
    

  }
	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Qiibee_Connect_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Qiibee_Connect_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/qiibee-connect-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Qiibee_Connect_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Qiibee_Connect_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/qiibee-connect-admin.js', array( 'jquery' ), $this->version, false );

	}

}
